@@ -1,7 +1,7 @@
 /** @file queryparser.h
  * @brief parsing a user query string to build a Xapian::Query object
  */
-/* Copyright (C) 2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+/* Copyright (C) 2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright (C) 2010 Adam Sjøgren
  *
  * This program is free software; you can redistribute it and/or
@@ -28,6 +28,7 @@
 #endif
 
 #include <xapian/attributes.h>
+#include <xapian/deprecated.h>
 #include <xapian/intrusive_ptr.h>
 #include <xapian/query.h>
 #include <xapian/termiterator.h>
@@ -891,6 +892,14 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     /// Assignment.
     QueryParser & operator=(const QueryParser & o);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+    /// Move constructor.
+    QueryParser(QueryParser && o);
+
+    /// Move assignment operator.
+    QueryParser & operator=(QueryParser && o);
+#endif
+
     /// Default constructor.
     QueryParser();
 
@@ -914,8 +923,8 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     /** Set the stemming strategy.
      *
      *  This controls how the query parser will apply the stemming algorithm.
-     *  Note that the stemming algorithm is only applied to words in
-     *  probabilistic fields - boolean filter terms are never stemmed.
+     *  Note that the stemming algorithm is only applied to words in free-text
+     *  fields - boolean filter terms are never stemmed.
      *
      *  @param strategy	The strategy to use - possible values are:
      *   - STEM_NONE:	Don't perform any stemming.  (default in Xapian <=
@@ -949,8 +958,8 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *
      *				The most useful values for this are OP_OR (the
      *				default) and OP_AND.  OP_NEAR, OP_PHRASE,
-     *				OP_ELITE_SET and OP_SYNONYM are also permitted.
-     *				Passing other values will result in
+     *				OP_ELITE_SET, OP_SYNONYM and OP_MAX are also
+     *				permitted.  Passing other values will result in
      *				InvalidArgumentError being thrown.
      */
     void set_default_op(Query::op default_op);
@@ -989,6 +998,8 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  @param flags	What to set the limit for (default:
      *			FLAG_WILDCARD|FLAG_PARTIAL, setting the limit for both
      *			wildcards and partial terms).
+     *
+     *  @since 1.3.3
      */
     void set_max_expansion(Xapian::termcount max_expansion,
 			   int max_type = Xapian::Query::WILDCARD_LIMIT_ERROR,
@@ -1011,7 +1022,7 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     /** Parse a query.
      *
      *  @param query_string  A free-text query as entered by a user
-     *  @param flags         Zero or more Query::feature_flag specifying
+     *  @param flags         Zero or more QueryParser::feature_flag specifying
      *		what features the QueryParser should support.  Combine
      *		multiple values with bitwise-or (|) (default FLAG_DEFAULT).
      *	@param default_prefix  The default term prefix to use (default none).
@@ -1035,7 +1046,7 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
 		      unsigned flags = FLAG_DEFAULT,
 		      const std::string &default_prefix = std::string());
 
-    /** Add a probabilistic term prefix.
+    /** Add a free-text field term prefix.
      *
      *  For example:
      *
@@ -1090,7 +1101,7 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  @endcode
      *
      *  This allows the user to restrict a search with site:xapian.org which
-     *  will be converted to Hxapian.org combined with any probabilistic
+     *  will be converted to Hxapian.org combined with any weighted
      *  query with @c Xapian::Query::OP_FILTER.
      *
      *  If multiple boolean filters are specified in a query for the same
